@@ -2,6 +2,7 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Parser."""
 from .. import config
+import re
 
 
 def _build_parser():
@@ -37,8 +38,16 @@ def _build_parser():
         return int(digits) * scale[units[0]]
 
     def _drop_sub(value):
-        value = str(value)
-        return value.lstrip("sub-")
+        """
+        Drop ``sub-`` prefix of participant labels.
+
+        >>> _drop_sub("s060")
+        's060'
+        >>> _drop_sub("sub-s060")
+        's060'
+
+        """
+        return re.sub(r"^sub-", "", str(value))
 
     def _bids_filter(value):
         from json import loads
@@ -183,6 +192,13 @@ Automated Quality Control and visual reports for Quality Assesment of structural
         help="Cast the input data to float32 if it's represented in higher precision "
         "(saves space and improves perfomance)",
     )
+    g_perfm.add_argument(
+        "--pdb",
+        dest="pdb",
+        action="store_true",
+        default=False,
+        help="open Python debugger (pdb) on exceptions",
+    )
 
     # Control instruments
     g_outputs = parser.add_argument_group("Instrumental options")
