@@ -1,7 +1,6 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import absolute_import, division, print_function, unicode_literals
-
+"""MRIQC resources."""
 from .config import Template, IndividualTemplate, GroupTemplate
+
+__all__ = ["Template", "IndividualTemplate", "GroupTemplate"]
