@@ -1,8 +1,7 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
+MRIQC - anatomical and functional workflows.
 
 .. automodule:: mriqc.workflows.anatomical
     :members:
@@ -17,6 +16,10 @@
 
 
 """
-from __future__ import print_function, division, absolute_import, unicode_literals
 from .anatomical import anat_qc_workflow
 from .functional import fmri_qc_workflow
+
+__all__ = [
+    'anat_qc_workflow',
+    'fmri_qc_workflow',
+]
